package
Version:
v0.0.8
Opens a new window with list of versions in this module.
Published: Mar 30, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package update handles self-update of the acli binary via GitHub Releases.
Install downloads and atomically replaces the current binary with the
specified release's asset for the current GOOS/GOARCH.
type Asset struct {
Name string `json:"name"`
BrowserDownloadURL string `json:"browser_download_url"`
}
Asset is a downloadable file attached to a release.
type Release struct {
TagName string `json:"tag_name"`
Body string `json:"body"`
Assets []Asset `json:"assets"`
}
Release represents a GitHub release.
LatestRelease queries the GitHub Releases API and returns the latest release.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.